[llvm-commits] CVS: llvm/lib/CodeGen/PrologEpilogInserter.cpp

Evan Cheng evan.cheng at apple.com
Tue Sep 26 15:29:45 PDT 2006



Changes in directory llvm/lib/CodeGen:

PrologEpilogInserter.cpp updated: 1.58 -> 1.59
---
Log message:

Rename function. It's determining which callee-save registers to save.

---
Diffs of the changes:  (+7 -7)

 PrologEpilogInserter.cpp |   14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)


Index: llvm/lib/CodeGen/PrologEpilogInserter.cpp
diff -u llvm/lib/CodeGen/PrologEpilogInserter.cpp:1.58 llvm/lib/CodeGen/PrologEpilogInserter.cpp:1.59
--- llvm/lib/CodeGen/PrologEpilogInserter.cpp:1.58	Sun Aug 27 07:54:01 2006
+++ llvm/lib/CodeGen/PrologEpilogInserter.cpp	Tue Sep 26 17:29:31 2006
@@ -43,11 +43,11 @@
         Fn.getFrameInfo()->setMachineDebugInfo(DI);
       }
       
-      // Scan the function for modified caller saved registers and insert spill
-      // code for any caller saved registers that are modified.  Also calculate
+      // Scan the function for modified callee saved registers and insert spill
+      // code for any callee saved registers that are modified.  Also calculate
       // the MaxCallFrameSize and HasCalls variables for the function's frame
       // information and eliminates call frame pseudo instructions.
-      calculateCallerSavedRegisters(Fn);
+      calculateCalleeSavedRegisters(Fn);
 
       // Add the code to save and restore the caller saved registers
       saveCallerSavedRegisters(Fn);
@@ -61,7 +61,7 @@
 
       // Add prolog and epilog code to the function.  This function is required
       // to align the stack frame as necessary for any stack variables or
       // called functions.  Because of this, calculateCallerSavedRegisters
       // must be called before this function in order to set the HasCalls
       // and MaxCallFrameSize variables.
       insertPrologEpilogCode(Fn);
@@ -75,7 +75,7 @@
     }
   
   private:
-    void calculateCallerSavedRegisters(MachineFunction &Fn);
+    void calculateCalleeSavedRegisters(MachineFunction &Fn);
     void saveCallerSavedRegisters(MachineFunction &Fn);
     void calculateFrameObjectOffsets(MachineFunction &Fn);
     void replaceFrameIndices(MachineFunction &Fn);
@@ -90,12 +90,12 @@
 FunctionPass *llvm::createPrologEpilogCodeInserter() { return new PEI(); }
 
 
-/// calculateCallerSavedRegisters - Scan the function for modified caller saved
+/// calculateCalleeSavedRegisters - Scan the function for modified caller saved
 /// registers.  Also calculate the MaxCallFrameSize and HasCalls variables for
 /// the function's frame information and eliminates call frame pseudo
 /// instructions.
 ///
-void PEI::calculateCallerSavedRegisters(MachineFunction &Fn) {
+void PEI::calculateCalleeSavedRegisters(MachineFunction &Fn) {
   const MRegisterInfo *RegInfo = Fn.getTarget().getRegisterInfo();
   const TargetFrameInfo *TFI = Fn.getTarget().getFrameInfo();
 
@@ -61,7 +61,7 @@
       // Add prolog and epilog code to the function.  This function is required
       // to align the stack frame as necessary for any stack variables or
-      // called functions.  Because of this, calculateCallerSavedRegisters
+      // called functions.  Because of this, calculateCalleeSavedRegisters
       // must be called before this function in order to set the HasCalls
       // and MaxCallFrameSize variables.






More information about the llvm-commits mailing list